//
//  SCAdListener.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <Foundation/Foundation.h>

@class SCAdViewController;
@class SCAdInfo;

/// Listener protocol which is informed about state changes from SCAdSDKController
@protocol SCAdListener <NSObject>
@optional
/**
 Called when advertisement playback has ended

 - Parameter controller: The parent controller
 */
- (void)onEndCallbackWith:(SCAdViewController*)controller;

/**
 Called when advertisement playback has started

 - Parameter controller: The parent controller
 */
- (void)onStartCallbackWith:(SCAdViewController*)controller;

/**
 Called when an emmpty video ad was delivered

 - Parameter controller: The parent controller
 */
- (void)onCappedCallbackWith:(SCAdViewController*)controller;

/**
 Called when prefetching of data for advertisement has finished

 - Parameter controller: The parent controller
 */
- (void)onPrefetchCompleteCallbackWith:(SCAdViewController*)controller __deprecated;

/**
 Called on for every ScAdInfo.Type change

 - Parameter controller: The parent controller
 - Parameter adInfo: current ScAdInfo
 */
- (void)onEventCallbackWith:(SCAdViewController*)controller info:(SCAdInfo*)info;

/**
 Called when the advertisement is clicked. You can prevent linking to the
 advertisers WebSite by catching click events.

 - Parameter controller: The parent controller
 - Parameter targetURL: the advertisement url to be opened

 - Returns: true if the given url could be successfully opened
 */
- (BOOL)onClickthruCallbackWith:(SCAdViewController*)controller targetURL:(NSURL*)url;
@end
